﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace LegendInCodeBehind
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            RadCartesianChart chart = new RadCartesianChart();
            chart.HorizontalAxis = new DateTimeCategoricalAxis();
            chart.VerticalAxis = new LinearAxis() { Maximum = 60 };
            chart.Palette = ChartPalettes.Windows8;

            //add Series
            for (int i = 0; i < 5; i++)
            {
                PointSeries valueSeries2 = new PointSeries();
                valueSeries2.ItemsSource = GetData(i);
                valueSeries2.FontSize = 1;
                valueSeries2.CategoryBinding = new PropertyNameDataPointBinding("Time");
                valueSeries2.ValueBinding = new PropertyNameDataPointBinding("Val");
                valueSeries2.Visibility = System.Windows.Visibility.Visible;
                valueSeries2.LegendSettings = new SeriesLegendSettings() { Title = "valueSeries" + i};
                chart.Series.Add(valueSeries2);
            }         

            //RadLegend
            RadLegend legendSettings = new RadLegend();
            legendSettings.Items = chart.LegendItems;
            legendSettings.ItemsPanel = App.Current.Resources["legendPanelTemplate"] as ItemsPanelTemplate;
            legendSettings.ItemTemplate = App.Current.Resources["legendTemplate"] as DataTemplate;
            legendSettings.Visibility = Visibility.Visible;
            legendSettings.DefaultMarkerGeometry = new EllipseGeometry() { Center = new System.Windows.Point(6, 6), RadiusX = 4, RadiusY = 4 };
            legendSettings.HorizontalAlignment = HorizontalAlignment.Center;


            Grid.SetRow(legendSettings, 1);
            this.LayoutRoot.Children.Add(chart);
            LayoutRoot.Children.Add(legendSettings);
  
        }

        public List<ChartData> GetData(int seed)
        {
            List<ChartData> data = new List<ChartData>();
            Random rnd = new Random((int)DateTime.Now.Ticks & 0x0000FFFF);
            data.Add(new ChartData(rnd.Next(seed, 50), new DateTime(2014, 01, 15)));
            data.Add(new ChartData(rnd.Next(seed, 50), new DateTime(2014, 02, 28)));
            data.Add(new ChartData(rnd.Next(seed, 50), new DateTime(2014, 04, 3)));
            data.Add(new ChartData(rnd.Next(seed, 50), new DateTime(2014, 09, 18)));
            data.Add(new ChartData(rnd.Next(seed, 50), new DateTime(2014, 11, 15)));
            return data;
        }
    }

    public class ViewModel : ViewModelBase
    {
        private List<ChartData> data;

        public List<ChartData> Data
        {
            get
            {
                return this.data;
            }
            set
            {
                if (this.data != value)
                {
                    this.data = value;
                    this.OnPropertyChanged("Data");
                }
            }
        } 
    }    

    public class ChartData
    {
        public ChartData(double x, DateTime time)
        {
            this.Val = x;
            this.Time = time;
        }

        public double Val { get; set; }

        public DateTime Time { get; set; }  
    }
}
